# GB Power Outage Monitoring

`outage` is a Python library for retrieving, parsing, and collating power outage data for the British electricity system.

<br>

To Do:

- [x] Add an outage map to the documentation, example [here](https://groups.google.com/g/mkdocs/c/qvwXYRuDM-M?pli=1)
- [ ] Make sure that all of the raw and cleaned JSON data is available from the GitHub pages site

<br>

### Use Cases

* Want to check you're having a power cut and ideally get an estimate for when it will be resolved
* Find out the average power cut time for an area, as well as how good their estimate for the length is
